==> openx-2.5.69-beta.tar.bz2: openx-2.5.69-beta/lib/max/language/ja/invocation.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.5                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: invocation.lang.php 21310 2008-06-12 11:12:19Z david.keen@openx.org $
*/

// Other
$GLOBALS['strCopyToClipboard']                      = "クリップボードにコピーする";
$GLOBALS['strCopy']                                 = "コピー";

// Measures
$GLOBALS['strAbbrPixels']                           = "ピクセル";
$GLOBALS['strAbbrSeconds']                          = "秒";

// Common Invocation Parameters
$GLOBALS['strInvocationWhat']                       = "バナーの選択";
$GLOBALS['strInvocationPreview']                    = "バナーのプレビュー";
$GLOBALS['strInvocationClientID']                   = "広告主";
$GLOBALS['strInvocationCampaignID']                 = "キャンペーン";
$GLOBALS['strInvocationTarget']                     = "ターゲットフレーム";
$GLOBALS['strInvocationSource']                     = "ソースパラメータ";
$GLOBALS['strInvocationWithText']                   = "バナー直下にテキストを表示する";
$GLOBALS['strInvocationDontShowAgain']              = "同一ページにバナーを再表示しない";
$GLOBALS['strInvocationDontShowAgainCampaign']      = "同一ページに同一キャンペーンを再表示しない";
$GLOBALS['strInvocationTemplate']                   = "テンプレートととして利用可能なようにバナーを変数内に保存する";
$GLOBALS['strInvocationBannerID']                   = "バナーID";
$GLOBALS['strInvocationComments']                   = "コメントを含める";

// Iframe
$GLOBALS['strIFrameRefreshAfter']                   = "リフレッシュ時間";
$GLOBALS['strIframeResizeToBanner']                 = "バナーサイズに応じてiframeをリサイズする";
$GLOBALS['strIframeMakeTransparent']                = "iframeを透過にする";
$GLOBALS['strIframeIncludeNetscape4']               = "Netscape4互換のilayerを含める";


// PopUp
$GLOBALS['strPopUpStyle']							= "ポップアップスタイル";
$GLOBALS['strPopUpStylePopUp']						= "ポップアップ";
$GLOBALS['strPopUpStylePopUnder']					= "ポップアンダー";
$GLOBALS['strPopUpCreateInstance']					= "ポップアップ作成時のインスタンス";
$GLOBALS['strPopUpImmediately']						= "直後";
$GLOBALS['strPopUpOnClose']							= "ページクローズ時";
$GLOBALS['strPopUpAfterSec']						= "秒後";
$GLOBALS['strAutoCloseAfter']						= "自動クローズ秒数";
$GLOBALS['strPopUpTop']								= "初期ポジション（トップ）";
$GLOBALS['strPopUpLeft']							= "初期ポジション（レフト）";
$GLOBALS['strWindowOptions']						= "ウィンドウオプション";
$GLOBALS['strShowToolbars']							= "ツールバー";
$GLOBALS['strShowLocation']							= "表示位置";
$GLOBALS['strShowMenubar']							= "メニューバー";
$GLOBALS['strShowStatus']							= "ステータス";
$GLOBALS['strWindowResizable']						= "サイズ可変";
$GLOBALS['strShowScrollbars']						= "スクロールバー";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']       				= "ホスト言語";
$GLOBALS['strXmlRpcProtocol']       				= "XML-RPCサーバとHTTPSで通信する";
$GLOBALS['strXmlRpcTimeout']        				= "XML-RPCタイムアウト秒数";


// AdLayer
$GLOBALS['strAdLayerStyle']							= "スタイル";

$GLOBALS['strAlignment']							= "位置あわせ";
$GLOBALS['strHAlignment']							= "水平方向";
$GLOBALS['strLeft']									= "左寄せ";
$GLOBALS['strCenter']								= "中央寄せ";
$GLOBALS['strRight']								= "右寄せ";

$GLOBALS['strVAlignment']							= "垂直方向";
$GLOBALS['strTop']									= "上配置";
$GLOBALS['strMiddle']								= "中配置";
$GLOBALS['strBottom']								= "下配置";

$GLOBALS['strAutoCollapseAfter']					= "自動消滅するまでの秒数";
$GLOBALS['strCloseText']							= "クローズ用テキスト";
$GLOBALS['strClose']								= "[閉じる]";
$GLOBALS['strBannerPadding']						= "バナー用パディング文字";

$GLOBALS['strHShift']								= "水平方向にシフト";
$GLOBALS['strVShift']								= "垂直方向にシフト";

$GLOBALS['strShowCloseButton']						= "クローズボタンを表示";
$GLOBALS['strBackgroundColor']						= "背景色";
$GLOBALS['strBorderColor']							= "境界色";

$GLOBALS['strDirection']							= "移動方向";
$GLOBALS['strLeftToRight']							= "左から右";
$GLOBALS['strRightToLeft']							= "右から左";
$GLOBALS['strLooping']								= "ループ状";
$GLOBALS['strAlwaysActive']							= "常にアクティブ";
$GLOBALS['strSpeed']								= "スピード";
$GLOBALS['strPause']								= "一時停止";
$GLOBALS['strLimited']								= "制限条件";
$GLOBALS['strLeftMargin']							= "左マージン";
$GLOBALS['strRightMargin']							= "右マージン";
$GLOBALS['strTransparentBackground']				= "背景の透過";

$GLOBALS['strSmoothMovement']						= "スムースに移動";
$GLOBALS['strHideNotMoving']						= "カーソル停止時はバナーを隠す";
$GLOBALS['strHideDelay']							= "バナー消滅までの遅延時間";
$GLOBALS['strHideTransparancy']						= "消滅バナーの透過度";


$GLOBALS['strAdLayerStyleName']	= array(
	'geocities'		=> "ジオシティーズ",
	'simple'		=> "シンプル",
	'cursor'		=> "カーソル",
	'floater'		=> "フローター"
);

// Support for 3rd party server clicktracking
$GLOBALS['str3rdPartyTrack']		 				= "他社クリック追跡をサポートする";

// Support for cachebusting code
$GLOBALS['strCacheBuster']		    				= "キャッシュ破棄コードを挿入する";

// Non-Img creatives Warning for zone image-only invocation
$GLOBALS['strNonImgWarningZone']					= "警告：このゾーンには非画像バナーが割り当てられています。このタグでは、非画像バナーがローテートされません。";
$GLOBALS['strNonImgWarning']        				= "警告：このタグは非画像バナーのため動作しません。";

// unkown HTML tag type Warning for zone invocation
$GLOBALS['strUnknHtmlWarning']      				= "警告：このバナーは未知のHTML広告フォーマットです。";

// sql/web banner-type warning for clickonly zone invocation
$GLOBALS['strWebBannerWarning']     				= "警告：指定したバナーはダウンロード可能となっていません。正しいURLを入力してください。
<br /> 1) バナーがダウンロード可能かテストしてください:";
$GLOBALS['strDwnldWebBanner']       				= "ここを右クリックして、保存先URLを選んでください：";
$GLOBALS['strWebBannerWarning2']    				= "<br /> 2) Webサイト上の正しいバナーURLを入力してください：";

// IMG invocation selected for tracker with appended code
$GLOBALS['strWarning'] 								= "警告";
$GLOBALS['strImgWithAppendWarning'] 				= "トラッカーコードを追加しました。追加コードは、<strong>Javescriptタグ</strong>で動作します。";

?>

==> openx-2.7.27-beta.tar.bz2: openx-2.7.27-beta/lib/max/language/ja/invocation.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.7                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: invocation.lang.php 29689 2008-12-03 16:30:29Z andrew.hill $
*/

// Other
$GLOBALS['strCopyToClipboard']                      = "クリップボードにコピーする";
$GLOBALS['strCopy']                                 = "コピー";

// Measures
$GLOBALS['strAbbrPixels']                           = "ピクセル";
$GLOBALS['strAbbrSeconds']                          = "秒";

// Common Invocation Parameters
$GLOBALS['strInvocationWhat']                       = "バナーの選択";
$GLOBALS['strInvocationPreview']                    = "バナーのプレビュー";
$GLOBALS['strInvocationClientID']                   = "広告主";
$GLOBALS['strInvocationCampaignID']                 = "キャンペーン";
$GLOBALS['strInvocationTarget']                     = "ターゲットフレーム";
$GLOBALS['strInvocationSource']                     = "ソースパラメータ";
$GLOBALS['strInvocationWithText']                   = "バナー直下にテキストを表示する";
$GLOBALS['strInvocationDontShowAgain']              = "同一ページにバナーを再表示しない";
$GLOBALS['strInvocationDontShowAgainCampaign']      = "同一ページに同一キャンペーンを再表示しない";
$GLOBALS['strInvocationTemplate']                   = "テンプレートととして利用可能なようにバナーを変数内に保存する";
$GLOBALS['strInvocationBannerID']                   = "バナーID";
$GLOBALS['strInvocationComments']                   = "コメントを含める";

// Iframe
$GLOBALS['strIFrameRefreshAfter']                   = "リフレッシュ時間";
$GLOBALS['strIframeResizeToBanner']                 = "バナーサイズに応じてiframeをリサイズする";
$GLOBALS['strIframeMakeTransparent']                = "iframeを透過にする";
$GLOBALS['strIframeIncludeNetscape4']               = "Netscape4互換のilayerを含める";


// PopUp
$GLOBALS['strPopUpStyle']							= "ポップアップスタイル";
$GLOBALS['strPopUpStylePopUp']						= "ポップアップ";
$GLOBALS['strPopUpStylePopUnder']					= "ポップアンダー";
$GLOBALS['strPopUpCreateInstance']					= "ポップアップ作成時のインスタンス";
$GLOBALS['strPopUpImmediately']						= "直後";
$GLOBALS['strPopUpOnClose']							= "ページクローズ時";
$GLOBALS['strPopUpAfterSec']						= "秒後";
$GLOBALS['strAutoCloseAfter']						= "自動クローズ秒数";
$GLOBALS['strPopUpTop']								= "初期ポジション（トップ）";
$GLOBALS['strPopUpLeft']							= "初期ポジション（レフト）";
$GLOBALS['strWindowOptions']						= "ウィンドウオプション";
$GLOBALS['strShowToolbars']							= "ツールバー";
$GLOBALS['strShowLocation']							= "表示位置";
$GLOBALS['strShowMenubar']							= "メニューバー";
$GLOBALS['strShowStatus']							= "ステータス";
$GLOBALS['strWindowResizable']						= "サイズ可変";
$GLOBALS['strShowScrollbars']						= "スクロールバー";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']       				= "ホスト言語";
$GLOBALS['strXmlRpcProtocol']       				= "XML-RPCサーバとHTTPSで通信する";
$GLOBALS['strXmlRpcTimeout']        				= "XML-RPCタイムアウト秒数";


// AdLayer
$GLOBALS['strAdLayerStyle']							= "スタイル";

$GLOBALS['strAlignment']							= "位置あわせ";
$GLOBALS['strHAlignment']							= "水平方向";
$GLOBALS['strLeft']									= "左寄せ";
$GLOBALS['strCenter']								= "中央寄せ";
$GLOBALS['strRight']								= "右寄せ";

$GLOBALS['strVAlignment']							= "垂直方向";
$GLOBALS['strTop']									= "上配置";
$GLOBALS['strMiddle']								= "中配置";
$GLOBALS['strBottom']								= "下配置";

$GLOBALS['strAutoCollapseAfter']					= "自動消滅するまでの秒数";
$GLOBALS['strCloseText']							= "クローズ用テキスト";
$GLOBALS['strClose']								= "[閉じる]";
$GLOBALS['strBannerPadding']						= "バナー用パディング文字";

$GLOBALS['strHShift']								= "水平方向にシフト";
$GLOBALS['strVShift']								= "垂直方向にシフト";

$GLOBALS['strShowCloseButton']						= "クローズボタンを表示";
$GLOBALS['strBackgroundColor']						= "背景色";
$GLOBALS['strBorderColor']							= "境界色";

$GLOBALS['strDirection']							= "移動方向";
$GLOBALS['strLeftToRight']							= "左から右";
$GLOBALS['strRightToLeft']							= "右から左";
$GLOBALS['strLooping']								= "ループ状";
$GLOBALS['strAlwaysActive']							= "常にアクティブ";
$GLOBALS['strSpeed']								= "スピード";
$GLOBALS['strPause']								= "中断";
$GLOBALS['strLimited']								= "制限条件";
$GLOBALS['strLeftMargin']							= "左マージン";
$GLOBALS['strRightMargin']							= "右マージン";
$GLOBALS['strTransparentBackground']				= "背景の透過";

$GLOBALS['strSmoothMovement']						= "スムースに移動";
$GLOBALS['strHideNotMoving']						= "カーソル停止時はバナーを隠す";
$GLOBALS['strHideDelay']							= "バナー消滅までの遅延時間";
$GLOBALS['strHideTransparancy']						= "消滅バナーの透過度";


$GLOBALS['strAdLayerStyleName']['geocities'] = "ジオシティーズシンプルカーソルフローター";
$GLOBALS['strAdLayerStyleName']['simple'] = "シンプル";
$GLOBALS['strAdLayerStyleName']['cursor'] = "カーソル";
$GLOBALS['strAdLayerStyleName']['floater'] = "フローター";


// Support for 3rd party server clicktracking
$GLOBALS['str3rdPartyTrack']		 				= "他社クリック追跡をサポートする";

// Support for cachebusting code
$GLOBALS['strCacheBuster']		    				= "キャッシュ破棄コードを挿入する";

// Non-Img creatives Warning for zone image-only invocation
$GLOBALS['strNonImgWarningZone']					= "警告：このゾーンには非画像バナーが割り当てられています。このタグでは、非画像バナーがローテートされません。";
$GLOBALS['strNonImgWarning']        				= "警告：このタグは非画像バナーのため動作しません。";

// unkown HTML tag type Warning for zone invocation
$GLOBALS['strUnknHtmlWarning']      				= "警告：このバナーは未知のHTML広告フォーマットです。";

// sql/web banner-type warning for clickonly zone invocation
$GLOBALS['strWebBannerWarning']     				= "警告：指定したバナーはダウンロード可能となっていません。正しいURLを入力してください。\n<br /> 1) バナーがダウンロード可能かテストしてください:";
$GLOBALS['strDwnldWebBanner']       				= "ここを右クリックして、保存先URLを選んでください：";
$GLOBALS['strWebBannerWarning2']    				= "<br /> 2) Webサイト上の正しいバナーURLを入力してください：";

// IMG invocation selected for tracker with appended code
$GLOBALS['strWarning'] 								= "警告";
$GLOBALS['strImgWithAppendWarning'] 				= "トラッカーコードを追加しました。追加コードは、<strong>Javescriptタグ</strong>で動作します。";



// Note: New translations not found in original lang files but found in CSV
$GLOBALS['strIframeGoogleClickTracking'] = "AdSenseのクリックを追跡するコードを含める";
$GLOBALS['strWarningLocalInvocation'] = "<span class='tab-s'><strong>注意</strong> ローカルバナーの生成は、広告を呼び出すサーバと、呼び出される広告のコードが、同じサーバ上にある場合にのみ、動作します。</span><br />MAX_PATHがベースディレクトリをさしているか、確認してください。<br />そして、広告を表示しているサーバの設定ファイルがMAX_PATH/varにあることを確認してください。";
$GLOBALS['strChooseTypeOfInvocation'] = "バナーの呼出方法を選択してください";
$GLOBALS['strChooseTypeOfBannerInvocation'] = "バナーの呼出方法を選択してください";
?>
